#include "expDecayDialog.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qcombobox.h>
#include <qlayout.h>
#include <qbuttongroup.h>
#include <qlineedit.h>


expDecayDialog::expDecayDialog( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    if ( !name )
	setName( "expDecayDialog" );
	setCaption(tr("QtiPlot - Verify initial guesses"));
    setMinimumSize( QSize( 310, 140 ) );
	setMaximumSize( QSize( 310, 140 ) );
    setMouseTracking( TRUE );
    setSizeGripEnabled( FALSE );
	
	GroupBox1 = new QButtonGroup( 2,QGroupBox::Horizontal,tr(""),this,"GroupBox1" );

	new QLabel( tr("Exponential Decay Fit of"), GroupBox1, "TextLabel1",0 );
	boxName = new QComboBox(GroupBox1, "boxName" );
	
	new QLabel( tr("First decay time (t1)"), GroupBox1, "TextLabel2",0 );
	boxFirst = new QLineEdit(GroupBox1, "boxOrder" );
	boxFirst->setText(tr("1"));
	
	new QLabel( tr("Second decay time (t2)"), GroupBox1, "TextLabel3",0 );
	boxSecond = new QLineEdit(GroupBox1, "boxPoints" );
	boxSecond->setText(tr("1"));
	
	thirdLabel=new QLabel( tr("Third decay time (t3)"), GroupBox1, "TextLabel5",0 );
	thirdLabel->hide();
	
	boxThird = new QLineEdit(GroupBox1, "boxOrder" );
	boxThird->setText(tr("1"));
	boxThird->hide();
	
	new QLabel( tr("Initial time"), GroupBox1, "TextLabel4",0 );
	boxStart = new QLineEdit(GroupBox1, "boxStart" );
	boxStart->setText(tr("0"));
	
	new QLabel( tr("Y Offset"), GroupBox1, "TextLabel5",0 );
	boxYOffset = new QLineEdit(GroupBox1, "boxEnd" );
	boxYOffset->setText(tr("0"));
	
	GroupBox2 = new QButtonGroup(1,QGroupBox::Horizontal,tr(""),this,"GroupBox2" );
	GroupBox2->setFlat (TRUE);
	GroupBox2->setLineWidth (0);
	
	buttonOk = new QPushButton(GroupBox2, "buttonOk" );
    buttonOk->setAutoDefault( TRUE );
    buttonOk->setDefault( TRUE );
   
    buttonCancel = new QPushButton(GroupBox2, "buttonCancel" );
    buttonCancel->setAutoDefault( TRUE );
	
	QHBoxLayout* hlayout = new QHBoxLayout(this,5,5, "hlayout");
    hlayout->addWidget(GroupBox1);
	hlayout->addWidget(GroupBox2);

    languageChange();
   
    // signals and slots connections
    connect( buttonOk, SIGNAL( clicked() ), this, SLOT( accept() ) );
    connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
}

/*
 *  Destroys the object and frees any allocated resources
 */
expDecayDialog::~expDecayDialog()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void expDecayDialog::languageChange()
{
    buttonOk->setText( tr( "&OK" ) );
	buttonCancel->setText( tr( "&Cancel" ) );
}

void expDecayDialog::show3Times()
{
	thirdLabel->show();
	boxThird->show();
}

void expDecayDialog::accept()
{
if (boxThird->isVisible())
	emit options3(boxName->currentText(),boxFirst->text().toDouble(),
				boxSecond->text().toDouble(), boxThird->text().toDouble(),
				boxStart->text().toDouble(),boxYOffset->text().toDouble());
else
	emit options(boxName->currentText(),boxFirst->text().toDouble(),
				boxSecond->text().toDouble(), boxStart->text().toDouble(),
				boxYOffset->text().toDouble());
close();
}

void expDecayDialog::setCurveNames(const QStringList& names)
{
boxName->insertStringList (names,-1);
}
